// BitRequirementException.cs created with MonoDevelop
// User: morganevans at 18:12 11/02/2009
//
// To change standard headers go to Edit->Preferences->Coding->Standard Headers
//

using System;

namespace UK_CO_MEVANSPN_libBitStream
{
	/// <summary>
	/// BitRequirementException objects are thrown when the calling method has passed a bit
	/// length that is either of insufficient length to store the value passed in the same 
	/// method call or that bit length is simply outside of range of 1-8 bits required for 
	/// the normal operation of the called method.
	/// </summary>
	public class BitRequirementException : Exception {
		/// <summary>
		/// Constructor creates an exception object holding both textual and numerical 
		/// information about the problem.
		/// </summary>
		/// <param name="_required_bits">
		/// The bit length that is inappropriate to the method called.
		/// A <see cref="System.Int32"/>
		/// </param>
		public BitRequirementException(int _required_bits) : base("Bit length requirement of " + _required_bits + " is invalid.") {
			required_bits = _required_bits;
		}
		
		/// <summary>
		/// Returns the invalid bit length associated with the method call.
		/// </summary>
		/// <returns>
		/// A <see cref="System.Int32"/>
		/// </returns>
		public int getBitCount() {
			return required_bits;
		}
		
		private int required_bits;
	}
}
